@@ -11,6 +11,8 @@
 #include <aws/io/logging.h>
 #include <aws/sdkutils/sdkutils.h>
 
+AWS_PUSH_SANE_WARNING_LEVEL
+
 #define AWS_C_AUTH_PACKAGE_ID 6
 
 /**
@@ -43,6 +45,10 @@ enum aws_auth_errors {
     AWS_AUTH_SIGV4A_SIGNATURE_VALIDATION_FAILURE,
     AWS_AUTH_CREDENTIALS_PROVIDER_COGNITO_SOURCE_FAILURE,
     AWS_AUTH_CREDENTIALS_PROVIDER_DELEGATE_FAILURE,
+    AWS_AUTH_SSO_TOKEN_PROVIDER_SOURCE_FAILURE,
+    AWS_AUTH_SSO_TOKEN_INVALID,
+    AWS_AUTH_SSO_TOKEN_EXPIRED,
+    AWS_AUTH_CREDENTIALS_PROVIDER_SSO_SOURCE_FAILURE,
 
     AWS_AUTH_ERROR_END_RANGE = AWS_ERROR_ENUM_END_RANGE(AWS_C_AUTH_PACKAGE_ID)
 };
@@ -79,5 +85,6 @@ AWS_AUTH_API
 void aws_auth_library_clean_up(void);
 
 AWS_EXTERN_C_END
+AWS_POP_SANE_WARNING_LEVEL
 
 #endif /* AWS_AUTH_AUTH_H */
